@@ -8,33 +8,46 @@
 @description   :   队列调度器
 """
 
-
 from .standard import StandardQueueScheduler
 from ._async import AsyncQueueScheduler
 from .base import BaseScheduler
-from ..model import MessageItem
-from typing import Callable
-import multiprocessing
+from ..model import MessageItem, SchedulerConfig
+from typing import Callable, Literal, Dict
+import logging
 
 
-SCHEDULER_TYPES = {"standard": StandardQueueScheduler, "async": AsyncQueueScheduler}
+SCHEDULER_TYPES: Dict[str, type[BaseScheduler]] = {
+    "standard": StandardQueueScheduler,
+    "async": AsyncQueueScheduler,
+}
+
+try:
+    from .qt import QtQueueScheduler
+
+    print(SCHEDULER_TYPES)
+    if QtQueueScheduler.is_available():
+        SCHEDULER_TYPES["qt"] = QtQueueScheduler
+except ImportError:
+    logging.warning(
+        "Qt is not available, if you want to use it, please install PyQt5/PyQt6/PySide6"
+    )
+
+SchedulerType = Literal["standard", "async", "qt"]
 
 
 class QueueScheduler(BaseScheduler):
     def __init__(
         self,
-        receive_thread_num=1,
-        task_thread_num=multiprocessing.cpu_count() * 2,
-        shard_num=4,
-        scheduler_type="standard",
+        scheduler_type: SchedulerType = "standard",
+        config: SchedulerConfig = SchedulerConfig(),
     ):
         scheduler_class = SCHEDULER_TYPES.get(scheduler_type, None)
-        if not scheduler_class:
+        if scheduler_class is None:
             raise ValueError(f"Invalid scheduler type: {scheduler_type}")
-        self.scheduler = scheduler_class(receive_thread_num, task_thread_num, shard_num)
+        self.scheduler = scheduler_class(config)
 
-        if self.scheduler:
-            self.queue_operation = self.scheduler.queue_operation
+        # if self.scheduler:
+        #     self.queue_operation = self.scheduler.queue_operation
 
     def send_message(self, message: MessageItem, callback: Callable):
         if not self.scheduler:
