@@ -256,6 +256,104 @@ impl QueueOperation {
         Ok(id)
     }
 
+    pub fn enqueue_batch(&self, messages: Vec<Bound<'_, PyDict>>) -> PyResult<Vec<String>> {
+        let mut conn = self.get_connection()?;
+        let tx = conn
+            .transaction()
+            .map_err(|e| PyErr::new::<pyo3::exceptions::PyRuntimeError, _>(e.to_string()))?;
+
+        let mut inserted_ids = Vec::new();
+        {
+            let mut stmt = tx
+                .prepare(
+                    "INSERT INTO messages (
+                id, type, status, content, createtime, updatetime, result,
+                priority, source, destination, retry_count, expire_time, tags, metadata
+            ) VALUES (?1, ?2, ?3, ?4, ?5, ?6, ?7, ?8, ?9, ?10, ?11, ?12, ?13, ?14)",
+                )
+                .map_err(|e| PyErr::new::<pyo3::exceptions::PyRuntimeError, _>(e.to_string()))?;
+            for message in messages {
+                let id: String = message.get_item("id")?.unwrap().extract()?;
+                let message_type: String = message.get_item("type")?.unwrap().extract()?;
+                let status: i32 = message.get_item("status")?.unwrap().extract()?;
+                let content: String = message.get_item("content")?.unwrap().extract()?;
+                let createtime: String = message.get_item("createtime")?.unwrap().extract()?;
+                let updatetime: String = message.get_item("updatetime")?.unwrap().extract()?;
+                let priority: i32 = message.get_item("priority")?.unwrap().extract()?;
+                let source: String = message.get_item("source")?.unwrap().extract()?;
+                let destination: String = message.get_item("destination")?.unwrap().extract()?;
+                let retry_count: i32 = message.get_item("retry_count")?.unwrap().extract()?;
+                let result: Option<String> = match message.get_item("result")? {
+                    Some(item) => {
+                        if item.is_none() {
+                            None
+                        } else {
+                            Some(item.extract()?)
+                        }
+                    }
+                    None => None,
+                };
+
+                let expire_time: Option<String> = match message.get_item("expire_time")? {
+                    Some(item) => {
+                        if item.is_none() {
+                            None
+                        } else {
+                            Some(item.extract()?)
+                        }
+                    }
+                    None => None,
+                };
+
+                let tags: Option<String> = match message.get_item("tags")? {
+                    Some(item) => {
+                        if item.is_none() {
+                            None
+                        } else {
+                            Some(item.extract()?)
+                        }
+                    }
+                    None => None,
+                };
+
+                let metadata: Option<String> = match message.get_item("metadata")? {
+                    Some(item) => {
+                        if item.is_none() {
+                            None
+                        } else {
+                            Some(item.extract()?)
+                        }
+                    }
+                    None => None,
+                };
+
+                stmt.execute(params![
+                    id,
+                    message_type,
+                    status,
+                    content,
+                    createtime,
+                    updatetime,
+                    result,
+                    priority,
+                    source,
+                    destination,
+                    retry_count,
+                    expire_time,
+                    tags,
+                    metadata,
+                ])
+                .map_err(|e| PyErr::new::<pyo3::exceptions::PyRuntimeError, _>(e.to_string()))?;
+
+                inserted_ids.push(id);
+            }
+        }
+
+        tx.commit()
+            .map_err(|e| PyErr::new::<pyo3::exceptions::PyRuntimeError, _>(e.to_string()))?;
+        Ok(inserted_ids)
+    }
+
     /// 出队
     /// Args:
     ///   - self: QueueOperation 实例
@@ -661,6 +759,28 @@ impl ShardedQueueOperation {
         self.shards[shard_index].enqueue(message)
     }
 
+    pub fn enqueue_batch(&self, messages: Vec<Bound<'_, PyDict>>) -> PyResult<Vec<String>> {
+        let mut shard_groups: HashMap<usize, Vec<Bound<'_, PyDict>>> = HashMap::new();
+        for message in messages {
+            let message_id_bound = message
+                .get_item("id")?
+                .ok_or_else(|| PyErr::new::<pyo3::exceptions::PyKeyError, _>("Missing is field"))?;
+            let message_id: String = message_id_bound.extract()?;
+            let shard_index = self._get_shard_index(&message_id);
+            shard_groups
+                .entry(shard_index)
+                .or_insert_with(Vec::new)
+                .push(message);
+        }
+        let mut all_ids = Vec::new();
+
+        for (shard_index, shard_messages) in shard_groups {
+            let shard_ids = self.shards[shard_index].enqueue_batch(shard_messages)?;
+            all_ids.extend(shard_ids);
+        }
+        Ok(all_ids)
+    }
+
     /// 获取消息
     /// Args:
     ///   - self: ShardedQueueOperation 实例
