@@ -1,8 +1,8 @@
-from queue_sqlite.mounter.task_mounter import TaskMounter
+from queue_sqlite.mounter import task
 from queue_sqlite.model import MessageItem
 
 
-@TaskMounter.task(meta={"task_name": "test"})
+@task(meta={"task_name": "test"})
 def example(message_item: MessageItem):
     def fibonacci_generator():
         a, b = 0, 1
@@ -16,4 +16,4 @@ def example(message_item: MessageItem):
     return message_item.to_json()
 
 
-# 输出：[0, 1, 1, 2, 3, 5, 8, 13, 21, 34]
\ No newline at end of file
+# 输出：[0, 1, 1, 2, 3, 5, 8, 13, 21, 34]
