@@ -11,14 +11,12 @@ class TestCore:
         task_mounter = core.TaskMounter(TaskMounter)
         task_mounter.get_task_list()
         print(
-            task_mounter.get_task_function("task")({"num": 1})(lambda x: x + 1).meta[  # type: ignore
-                "num"
-            ]
+            f"task: {task_mounter.get_task_function("task")({"num": 1})(lambda x: x + 1).meta}"
         )
         from tasks import example
 
         task_mounter.get_task_list()
-        print(task_mounter.get_task_function("<lambda>"))
+        print(task_mounter.get_task_function("<lambda>")(1))
 
     @classmethod
     def test_queue_operation_init_db(cls):
